@@ -10,7 +10,7 @@ class Energy(Quantity):
 
     @Jmol.setter
     def Jmol(self, value):
-        self.si = to_float(value)
+        self.si = self.to_float(value)
 
     @property
     def kJmol(self):
@@ -18,7 +18,7 @@ class Energy(Quantity):
 
     @kJmol.setter
     def kJmol(self, value):
-        self.si = to_float(value * 1000)
+        self.si = self.to_float(value * 1000)
 
     @property
     def kcalmol(self):
@@ -26,4 +26,4 @@ class Energy(Quantity):
 
     @kcalmol.setter
     def kcalmol(self, value):
-        self.si = to_float(value * 4184)
+        self.si = self.to_float(value * 4184)
