@@ -1,7 +1,7 @@
 from .quantity import Quantity
 from .energy import Energy
 from .temperature import Temperature
-from catrxneng.utils import *
+from catrxneng import utils
 
 
 class Entropy(Quantity):
@@ -12,7 +12,7 @@ class Entropy(Quantity):
 
     @JmolK.setter
     def JmolK(self, value):
-        self.si = to_float(value)
+        self.si = self.to_float(value)
 
     @property
     def kJmolK(self):
@@ -20,18 +20,20 @@ class Entropy(Quantity):
 
     @kJmolK.setter
     def kJmolK(self, value):
-        self.si = to_float(value * 1000)
+        self.si = utils.self.to_float(value * 1000)
 
     def __mul__(self, other):
+        keys = self.get_keys(self, other)
         if isinstance(other, Temperature):
             si = self.si * other.si
-            return Energy(si=si)
+            return Energy(si=si, keys=keys)
         else:
             return super().__mul__(other)
 
     def __rmul__(self, other):
+        keys = self.get_keys(self, other)
         if isinstance(other, Temperature):
             si = other.si * self.si
-            return Energy(si=si)
+            return Energy(si=si, keys=keys)
         else:
             return super().__rmul__(other)
