@@ -10,7 +10,7 @@ class InversePressure(Quantity):
 
     @inv_Pa.setter
     def inv_Pa(self, value):
-        self.si = to_float(value)
+        self.si = self.to_float(value)
 
     @property
     def inv_bar(self):
@@ -18,28 +18,28 @@ class InversePressure(Quantity):
 
     @inv_bar.setter
     def inv_bar(self, value):
-        self.si = to_float(value) / 100000
+        self.si = self.to_float(value) / 100000
 
     @property
     def inv_kPa(self):
-        return self.si * 1000 
+        return self.si * 1000
 
     @inv_kPa.setter
     def inv_kPa(self, value):
-        self.si = to_float(value) / 1000
+        self.si = self.to_float(value) / 1000
 
     @property
     def inv_atm(self):
-        return self.si * 101325 
+        return self.si * 101325
 
     @inv_atm.setter
     def inv_atm(self, value):
-        self.si = to_float(value) / 101325
+        self.si = self.to_float(value) / 101325
 
     @property
     def inv_MPa(self):
-        return self.si * 1000000 
+        return self.si * 1000000
 
     @inv_MPa.setter
     def inv_MPa(self, value):
-        self.si = to_float(value) / 1000000
\ No newline at end of file
+        self.si = self.to_float(value) / 1000000
