@@ -10,7 +10,7 @@ class Mass(Quantity):
 
     @kg.setter
     def kg(self, value):
-        self.si = to_float(value)
+        self.si = self.to_float(value)
 
     @property
     def g(self):
@@ -18,24 +18,24 @@ class Mass(Quantity):
 
     @g.setter
     def g(self, value):
-        self.si = to_float(value) / 1000
+        self.si = self.to_float(value) / 1000
 
     def __mul__(self, other):
-        from .ghsv import GHSV 
+        from .whsv import WHSV
         from .molar_flow_rate import MolarFlowRate
         from .reaction_rate import ReactionRate
 
-        if isinstance(other, (GHSV, ReactionRate)):
+        if isinstance(other, (WHSV, ReactionRate)):
             si = self.si * other.si
             return MolarFlowRate(si=si)
         return super().__mul__(other)
 
     def __rmul__(self, other):
-        from .ghsv import GHSV 
+        from .whsv import WHSV
         from .molar_flow_rate import MolarFlowRate
         from .reaction_rate import ReactionRate
 
-        if isinstance(other, (GHSV, ReactionRate)):
+        if isinstance(other, (WHSV, ReactionRate)):
             si = self.si * other.si
             return MolarFlowRate(si=si)
         return super().__rmul__(other)
