@@ -1,5 +1,4 @@
 from .quantity import Quantity
-from catrxneng.utils import *
 
 
 class Temperature(Quantity):
@@ -10,7 +9,7 @@ class Temperature(Quantity):
 
     @K.setter
     def K(self, value):
-        self.si = to_float(value)
+        self.si = self.to_float(value)
 
     @property
     def C(self):
@@ -18,11 +17,12 @@ class Temperature(Quantity):
 
     @C.setter
     def C(self, value):
-        self.si = to_float(value + 273)
+        self.si = self.to_float(value + 273)
 
     def __mul__(self, other):
         from .energy import Energy
         from .entropy import Entropy
+
         if isinstance(other, Entropy):
             si = self.si * other.si
             return Energy(si=si)
@@ -32,6 +32,7 @@ class Temperature(Quantity):
     def __rmul__(self, other):
         from .energy import Energy
         from .entropy import Entropy
+
         if isinstance(other, Entropy):
             si = other.si * self.si
             return Energy(si=si)
