@@ -10,7 +10,7 @@ class VolumetricFlowRate(Quantity):
 
     @m3s.setter
     def m3s(self, value):
-        self.si = to_float(value)
+        self.si = self.to_float(value)
 
     @property
     def mLs(self):
@@ -18,4 +18,4 @@ class VolumetricFlowRate(Quantity):
 
     @mLs.setter
     def mLs(self, value):
-        self.si = to_float(value) / 1000 / 1000
\ No newline at end of file
+        self.si = self.to_float(value) / 1000 / 1000
